==> ogre_1.7.4+dfsg1.orig.tar.xz: ogre-1.7.4+dfsg1/Tools/MaterialEditor/MaterialEditor/src/SelectionService.cpp <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2011 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#include "SelectionService.h"

#include "SelectionEventArgs.h"

template<> SelectionService* Ogre::Singleton<SelectionService>::ms_Singleton = 0;

SelectionService& SelectionService::getSingleton(void)
{  
	assert( ms_Singleton );  return ( *ms_Singleton );  
}

SelectionService* SelectionService::getSingletonPtr(void)
{
	return ms_Singleton;
}

SelectionService::SelectionService()
{
	registerEvents();
}

SelectionService::~SelectionService()
{
}

void SelectionService::registerEvents()
{
	registerEvent(SelectionChanged);
}

const SelectionList& SelectionService::getSelection() const
{
	return mSelection;
}

void SelectionService::setSelection(boost::any& sel)
{
	mSelection.clear();
	
	mSelection.push_back(sel);
	
	fireEvent(SelectionChanged, SelectionEventArgs(mSelection));
}

void SelectionService::setSelection(const SelectionList& sel)
{
	mSelection = sel;

	fireEvent(SelectionChanged, SelectionEventArgs(mSelection));
}

==> ogre-1.9_1.9.0+dfsg1.orig.tar.xz: ogre-1.9.0/Tools/MaterialEditor/MaterialEditor/src/SelectionService.cpp <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2013 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#include "SelectionService.h"

#include "SelectionEventArgs.h"

template<> SelectionService* Ogre::Singleton<SelectionService>::msSingleton = 0;

SelectionService& SelectionService::getSingleton(void)
{  
	assert( msSingleton );  return ( *msSingleton );  
}

SelectionService* SelectionService::getSingletonPtr(void)
{
	return msSingleton;
}

SelectionService::SelectionService()
{
	registerEvents();
}

SelectionService::~SelectionService()
{
}

void SelectionService::registerEvents()
{
	registerEvent(SelectionChanged);
}

const SelectionList& SelectionService::getSelection() const
{
	return mSelection;
}

void SelectionService::setSelection(boost::any& sel)
{
	mSelection.clear();
	
	mSelection.push_back(sel);
	
	fireEvent(SelectionChanged, SelectionEventArgs(mSelection));
}

void SelectionService::setSelection(const SelectionList& sel)
{
	mSelection = sel;

	fireEvent(SelectionChanged, SelectionEventArgs(mSelection));
}
